@@ -1,5 +1,6 @@
 import asyncio
 import random
+from typing import Callable, List
 
 import attrs
 import pytest
@@ -20,13 +21,13 @@ from tests.po_lib_to_return import (
 )
 from web_poet import (
     HttpResponse,
-    Injectable,
     ItemPage,
+    WebPage,
     field,
     item_from_fields,
     item_from_fields_sync,
 )
-from web_poet.fields import get_fields_dict
+from web_poet.fields import FieldsMixin, get_fields_dict
 
 
 @attrs.define
@@ -40,11 +41,11 @@ class Page(ItemPage[Item]):
     response: HttpResponse
 
     @field
-    def name(self):  # noqa: D102
+    def name(self):
         return self.response.css("title ::text").get()
 
     @field
-    async def price(self):  # noqa: D102
+    async def price(self):
         await asyncio.sleep(0.01)
         return "$123"
 
@@ -54,11 +55,11 @@ class InvalidPage(ItemPage[Item]):
     response: HttpResponse
 
     @field
-    def name(self):  # noqa: D102
+    def name(self):
         return self.response.css("title ::text").get()
 
     @field
-    def unknown_attribute(self):  # noqa: D102
+    def unknown_attribute(self):
         return "foo"
 
 
@@ -94,10 +95,10 @@ def test_item_from_fields_sync() -> None:
     @attrs.define
     class Page(ItemPage):
         @field
-        def name(self):  # noqa: D102
+        def name(self):
             return "name"
 
-        def to_item(self):  # noqa: D102
+        def to_item(self):
             return item_from_fields_sync(self, dict)
 
     page = Page()
@@ -112,10 +113,10 @@ def test_field_non_callable() -> None:
             # https://github.com/python/mypy/issues/1362#issuecomment-438246775
             @field  # type: ignore
             @property
-            def name(self):  # noqa: D102
+            def name(self):
                 return "name"
 
-            def to_item(self):  # noqa: D102
+            def to_item(self):
                 return item_from_fields_sync(self, dict)
 
 
@@ -126,10 +127,10 @@ def test_field_classmethod() -> None:
         class Page(ItemPage):
             @field
             @classmethod
-            def name(cls):  # noqa: D102
+            def name(cls):
                 return "name"
 
-            def to_item(self):  # noqa: D102
+            def to_item(self):
                 return item_from_fields_sync(self, dict)
 
 
@@ -159,7 +160,7 @@ def test_field_decorator_no_arguments() -> None:
 
 
 def test_field_cache_sync() -> None:
-    class Page:
+    class Page(ItemPage):
         _n_called_1 = 0
         _n_called_2 = 0
 
@@ -187,7 +188,7 @@ def test_field_cache_sync() -> None:
 
 @pytest.mark.asyncio
 async def test_field_cache_async() -> None:
-    class Page:
+    class Page(ItemPage):
         _n_called_1 = 0
         _n_called_2 = 0
 
@@ -215,7 +216,7 @@ async def test_field_cache_async() -> None:
 
 @pytest.mark.asyncio
 async def test_field_cache_async_locked() -> None:
-    class Page:
+    class Page(ItemPage):
         _n_called = 0
 
         @field(cached=True)
@@ -257,18 +258,18 @@ async def test_skip_nonitem_fields_async() -> None:
 
 def test_skip_nonitem_fields() -> None:
     @attrs.define
-    class SyncPage(Injectable):
+    class SyncPage(ItemPage):
         response: HttpResponse
 
         @field
-        def name(self):  # noqa: D102
+        def name(self):
             return self.response.css("title ::text").get()
 
         @field
-        def price(self):  # noqa: D102
+        def price(self):
             return "$123"
 
-        def to_item(self):  # noqa: D102
+        def to_item(self) -> Item:  # type: ignore[override]
             return item_from_fields_sync(self, Item)
 
     class ExtendedPage(SyncPage):
@@ -281,7 +282,7 @@ def test_skip_nonitem_fields() -> None:
         page.to_item()
 
     class ExtendedPage2(ExtendedPage):
-        def to_item(self) -> Item:
+        def to_item(self) -> Item:  # type: ignore[override]
             return item_from_fields_sync(self, Item, skip_nonitem_fields=True)
 
     page = ExtendedPage2(response=EXAMPLE_RESPONSE)
@@ -355,6 +356,23 @@ def test_field_subclassing() -> None:
     assert list(get_fields_dict(Page2)) == ["field1", "field3", "field2"]
 
 
+def test_field_subclassing_super() -> None:
+    class Page(ItemPage):
+        @field
+        def field1(self):
+            return 1
+
+    class Page2(Page):
+        @field
+        def field1(self):
+            return super().field1 + 1
+
+    page = Page()
+    assert page.field1 == 1
+    page2 = Page2()
+    assert page2.field1 == 2
+
+
 def test_field_subclassing_from_to_item() -> None:
     # to_item() should be the same since it was not overridden from the
     # subclass.
@@ -483,7 +501,7 @@ def test_field_processors_sync() -> None:
     @attrs.define
     class Page(ItemPage):
         @field(out=[str.strip, proc1])
-        def name(self):  # noqa: D102
+        def name(self):
             return "  name\t "
 
     page = Page()
@@ -498,20 +516,218 @@ async def test_field_processors_async() -> None:
     @attrs.define
     class Page(ItemPage):
         @field(out=[str.strip, proc1])
-        async def name(self):  # noqa: D102
+        async def name(self):
             return "  name\t "
 
     page = Page()
     assert await page.name == "namex"
 
 
+def test_field_processors_inheritance() -> None:
+    def proc1(s):
+        return s + "x"
+
+    class BasePage(ItemPage):
+        @field(out=[str.strip, proc1])
+        def name(self):
+            return "  name\t "
+
+    class Page(BasePage):
+        @field(out=[str.strip])
+        def name(self):
+            return "  name\t "
+
+    base_page = BasePage()
+    assert base_page.name == "namex"
+    page = Page()
+    assert page.name == "name"
+
+
+def test_field_processors_page() -> None:
+    def proc1(s, page):
+        return page.prefix + s + "x"
+
+    class Page(ItemPage):
+        @field(out=[str.strip, proc1])
+        def name(self):
+            return "  name\t "
+
+        @field
+        def prefix(self):
+            return "prefix: "
+
+    page = Page()
+    assert page.name == "prefix: namex"
+
+
+def test_field_processors_multiple_pages() -> None:
+    def proc(value, page):
+        return page.body + value
+
+    class Page(WebPage):
+        @field
+        def body(self):
+            return self.response.text
+
+        @field(out=[proc])
+        def processed(self):
+            return "suffix"
+
+    page1 = Page(response=HttpResponse("https://example.com", b"page1"))
+    page2 = Page(response=HttpResponse("https://example.com", b"page2"))
+    assert page1.body == "page1"
+    assert page1.processed == "page1suffix"
+    assert page2.body == "page2"
+    assert page2.processed == "page2suffix"
+
+
+def test_field_processors_circular() -> None:
+    def proc1(s, page):
+        return s + page.b
+
+    def proc2(s, page):
+        return s + page.a
+
+    class Page(ItemPage):
+        @field(out=[proc1])
+        def a(self):
+            return "a"
+
+        @field(out=[proc2])
+        def b(self):
+            return "b"
+
+    page = Page()
+    with pytest.raises(RecursionError):
+        page.a
+    with pytest.raises(RecursionError):
+        page.b
+
+
+def test_field_processors_default() -> None:
+    @attrs.define
+    class BasePage(ItemPage):
+        class Processors:
+            name = [str.strip]
+
+        @field
+        def name(self):
+            return "  name\t "
+
+    class Page(BasePage):
+        pass
+
+    base_page = BasePage()
+    assert base_page.name == "name"
+
+    page = Page()
+    assert page.name == "name"
+
+
+def test_field_processors_override() -> None:
+    def proc1(s):
+        return s + "x"
+
+    class BasePage(ItemPage):
+        class Processors:
+            f1: List[Callable] = [str.strip]
+            f2 = [str.strip]
+            f3 = [str.strip]
+            f4: List[Callable] = [str.strip]
+            f5: List[Callable] = [str.strip]
+
+        @field
+        def f1(self):
+            return "  f1\t "
+
+        @field(out=[])
+        def f2(self):
+            return "  f2\t "
+
+        @field
+        def f3(self):
+            return "  f3\t "
+
+        @field
+        def f4(self):
+            return "  f4\t "
+
+        @field
+        def f5(self):
+            return "  f5\t "
+
+    class Page(BasePage):
+        class Processors(BasePage.Processors):
+            f1 = [proc1]
+            f4 = BasePage.Processors.f4 + [proc1]
+
+        @field(out=BasePage.Processors.f5 + [proc1])
+        def f5(self):
+            return "  f5\t "
+
+    base_page = BasePage()
+    assert base_page.f1 == "f1"
+    assert base_page.f2 == "  f2\t "
+    assert base_page.f3 == "f3"
+    assert base_page.f4 == "f4"
+    assert base_page.f5 == "f5"
+
+    page = Page()
+    assert page.f1 == "  f1\t x"
+    assert page.f2 == "  f2\t "
+    assert page.f3 == "f3"
+    assert page.f4 == "f4x"
+    assert page.f5 == "f5x"
+
+
+def test_field_processors_super() -> None:
+    class BasePage(ItemPage):
+        class Processors:
+            name = [str.strip]
+            desc = [str.strip]
+
+        @field
+        def name(self):
+            return "name "
+
+        @field
+        def desc(self):
+            return "desc "
+
+    class Page(BasePage):
+        class Processors(BasePage.Processors):
+            name: List[Callable] = []
+
+        @field
+        def name(self):
+            base_name = super().name
+            return base_name + "2 "
+
+    class Page2(Page):
+        class Processors(Page.Processors):
+            name: List[Callable] = []
+            desc: List[Callable] = []
+
+        @field
+        def desc(self):
+            base_desc = super().desc
+            return base_desc + "2 "
+
+    base_page = BasePage()
+    assert base_page.name == "name"
+    page = Page()
+    assert page.name == "name 2 "
+    page2 = Page2()
+    assert page2.desc == "desc 2 "
+
+
 def test_field_mixin() -> None:
     class A(ItemPage):
         @field
         def a(self):
             return None
 
-    class Mixin:
+    class Mixin(FieldsMixin):
         @field
         def mixin(self):
             return None
@@ -521,4 +737,11 @@ def test_field_mixin() -> None:
         def b(self):
             return None
 
+    class C(Mixin, A):
+        @field
+        def c(self):
+            return None
+
+    assert set(get_fields_dict(A)) == {"a"}
     assert set(get_fields_dict(B)) == {"a", "b", "mixin"}
+    assert set(get_fields_dict(C)) == {"a", "c", "mixin"}
