@@ -12,7 +12,7 @@ from .page_inputs import (
     RequestUrl,
     ResponseUrl,
 )
-from .pages import Injectable, ItemPage, ItemWebPage, Returns, WebPage
+from .pages import Injectable, ItemPage, ItemWebPage, Returns, WebPage, validates_input
 from .requests import request_downloader_var
 from .rules import (
     ApplyRule,
